==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/jabberdiskplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/jabberdiskplugin/jabberdisk.png
  0x0,0x0,0x4,0x10,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xd,0xd7,0x0,0x0,0xd,0xd7,
  0x1,0x42,0x28,0x9b,0x78,0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,
  0x74,0x77,0x61,0x72,0x65,0x0,0x77,0x77,0x77,0x2e,0x69,0x6e,0x6b,0x73,0x63,0x61,
  0x70,0x65,0x2e,0x6f,0x72,0x67,0x9b,0xee,0x3c,0x1a,0x0,0x0,0x3,0x9d,0x49,0x44,
  0x41,0x54,0x78,0xda,0x45,0x90,0x6b,0x4c,0x5b,0x65,0x18,0xc7,0x1f,0x6,0x35,0x31,
  0x9b,0x9b,0x42,0x8c,0xc1,0x68,0xb7,0xc4,0x65,0x86,0x9e,0x32,0x74,0x99,0xd1,0x80,
  0x6b,0xb3,0x2f,0x26,0xe,0xa3,0xc1,0xb,0xe1,0x83,0x31,0x4b,0x16,0x81,0xd1,0xae,
  0x37,0x39,0x20,0x2d,0x3d,0xe7,0x74,0x2d,0x44,0xb1,0x68,0x3a,0xa7,0xc6,0xdb,0x62,
  0xb2,0xb,0x9b,0x1f,0x4c,0x18,0x85,0xb5,0xa1,0x6d,0xb6,0x5e,0x29,0x50,0x7a,0x3b,
  0xa5,0x3d,0x2d,0xbd,0x84,0xb1,0x69,0x14,0x62,0x5c,0x18,0xd9,0x4e,0xed,0x79,0x3d,
  0xa7,0x9b,0xe3,0xc3,0xef,0xbd,0x3d,0xcf,0xff,0xff,0xfe,0xdf,0x17,0x28,0x8a,0x2,
  0x8a,0x22,0x81,0x22,0xf9,0xd9,0x44,0xc0,0xe9,0xc1,0x2f,0x60,0xc0,0x64,0x82,0xe1,
  0x89,0x63,0x30,0xe0,0x6a,0xe6,0x69,0x1,0xe3,0x64,0x1b,0xe0,0x63,0x5a,0x30,0xf5,
  0x8f,0x3,0x45,0x90,0x40,0xfe,0xdf,0xcf,0x6b,0xab,0x83,0xb0,0x11,0xe,0x9,0x83,
  0x19,0x86,0xbf,0xee,0x1,0x65,0xf0,0x80,0xa8,0xc7,0xfb,0x44,0xab,0xda,0xf7,0x7c,
  0xbf,0xda,0x2f,0xd6,0xf5,0xf9,0xf7,0xb4,0x2a,0x23,0xcf,0xee,0x56,0x4f,0xbc,0x57,
  0x4b,0x10,0xa7,0x81,0x24,0x1f,0x98,0x8,0x54,0xd,0x8,0x8a,0x0,0x13,0x2f,0x1e,
  0xb4,0xea,0xa0,0x97,0xde,0xbd,0x53,0xe5,0x6b,0xc0,0x6d,0x8b,0x5d,0x7f,0x5f,0x2d,
  0x59,0xd0,0x54,0x69,0x4,0xd9,0x22,0x5d,0x7f,0xa9,0x7c,0xcf,0xf4,0xab,0xf2,0x8f,
  0x35,0x1a,0x7e,0xf8,0xb0,0x96,0x1a,0x1a,0xad,0x6a,0x84,0x8b,0x1f,0xba,0x11,0x40,
  0xe,0x8d,0x80,0x7e,0xf2,0x88,0x48,0x19,0xd9,0x79,0xd4,0xe8,0x6b,0xbb,0x65,0x64,
  0xa4,0xff,0x10,0xcb,0x2d,0xeb,0x86,0xe5,0xe6,0xd,0x82,0x91,0x6e,0x1a,0x3,0xad,
  0x37,0x95,0xe1,0x27,0xdf,0x1a,0x9c,0x17,0x3f,0x45,0x59,0xc,0x40,0x1a,0xa9,0xed,
  0x4,0x24,0xc9,0xbb,0xd,0x9b,0x6b,0x3e,0xf5,0x4b,0x1e,0x57,0x2e,0x36,0x74,0x8f,
  0x2d,0xbd,0x76,0x77,0xb6,0x70,0x68,0x73,0x8c,0x7e,0xee,0xde,0x99,0xd4,0x3e,0xf6,
  0x5b,0xe6,0x85,0x3b,0xc6,0xc5,0x43,0x9b,0xea,0x50,0xa3,0xe,0xcf,0x3c,0xdd,0x48,
  0x58,0x35,0x35,0x24,0x9f,0x58,0x48,0xb1,0xfd,0x9e,0x61,0x33,0x28,0xed,0xfb,0xf7,
  0x9c,0xf0,0xd7,0xbd,0x6f,0x8,0x62,0x37,0x6f,0x94,0xe4,0x6c,0xb8,0xf4,0x46,0x39,
  0x58,0x7a,0xb3,0x7c,0x7e,0xe5,0xd5,0x7b,0x9f,0x4,0xe,0xac,0x76,0x7b,0x77,0x1d,
  0x3f,0x19,0xdc,0x25,0x26,0x3e,0xd7,0x2,0x65,0x34,0x57,0x2f,0x16,0xc,0xea,0x84,
  0x14,0xa,0x85,0xe2,0xf0,0xa5,0xa9,0x9f,0xf2,0x57,0x7c,0x5f,0xde,0x3a,0x3b,0x7f,
  0x7c,0x4b,0x9f,0x3c,0x58,0x19,0x5b,0x3e,0x5a,0xf9,0x8c,0xc7,0x98,0x7c,0xb9,0x72,
  0x76,0xfe,0xa3,0xad,0xb,0x7e,0xcb,0xef,0x17,0xec,0x67,0xa,0xa7,0x4e,0x29,0xe,
  0x93,0x64,0x35,0xf9,0xe,0x30,0x9b,0xcd,0x22,0x1c,0xc7,0x61,0xfc,0x2b,0xeb,0xb9,
  0xdb,0x6b,0x7f,0x20,0x9a,0x89,0x21,0x3f,0x33,0x89,0x7e,0xa4,0x3f,0x40,0xdf,0x17,
  0xdf,0xe1,0x79,0x1b,0xfd,0x9c,0xea,0x44,0xd7,0x99,0x5f,0x51,0x8c,0x9,0xa1,0xb5,
  0xd5,0xdb,0xc8,0x3a,0x6e,0x3d,0x87,0xf,0xe0,0x60,0x32,0x99,0x44,0x60,0xb1,0x8c,
  0x80,0x46,0xa3,0x6e,0xf0,0x78,0xdc,0xeb,0xa5,0x52,0xe9,0xdf,0x4c,0x26,0x55,0x5e,
  0x88,0xc5,0xb8,0x1b,0x9e,0x6e,0x2e,0x10,0x3f,0xc8,0x79,0x63,0x12,0xee,0xba,0xe7,
  0x63,0x2e,0x42,0xc7,0xb9,0x74,0x86,0x2e,0xb,0x3d,0x6e,0x8f,0x6b,0x5d,0xa3,0xd5,
  0xd4,0x5b,0x2c,0x16,0x0,0xbd,0x5e,0xf,0x7a,0xc3,0x50,0x37,0xc3,0x30,0x28,0x9d,
  0x4e,0xb3,0x99,0x4c,0x86,0x4b,0xd1,0x29,0xce,0xeb,0xf5,0xa2,0x6b,0x57,0xcf,0x23,
  0xfb,0x6f,0xbf,0x20,0x97,0xcb,0x8d,0x96,0x96,0xa2,0x1c,0x5f,0xe7,0x1e,0xf6,0x20,
  0x5e,0x73,0x42,0xf8,0x3f,0xe8,0xed,0xed,0x11,0x5d,0xbe,0x3c,0xe1,0xcf,0x17,0x72,
  0x5c,0x86,0xc9,0x94,0xf3,0xf9,0x3c,0xc7,0x83,0xf2,0x85,0x3c,0xca,0xae,0x94,0x10,
  0x93,0x2b,0xa2,0x5c,0x2e,0x87,0xa,0xfc,0xbe,0x50,0x28,0x70,0xd9,0x6c,0xb6,0xcc,
  0xd7,0xb8,0x4b,0x13,0x17,0x83,0x6a,0xb5,0x1a,0xa0,0xaf,0xef,0xe4,0xfe,0xd9,0x59,
  0xe7,0x46,0x3e,0xbd,0xca,0xc5,0xa3,0xc9,0x4a,0x34,0x16,0x45,0xf1,0x78,0x1c,0x25,
  0x12,0x9,0x94,0x4c,0x26,0x10,0x4d,0x27,0x79,0x68,0xb4,0xb0,0xb0,0x80,0x22,0x91,
  0x88,0x30,0x57,0x8a,0xc5,0x22,0xe7,0x72,0xbb,0xee,0x2a,0x14,0x7d,0xb5,0xa0,0xd1,
  0xaa,0x5e,0x74,0xce,0xcc,0xfe,0xf9,0xcd,0x35,0x9c,0x9d,0x74,0x5f,0xbc,0x1f,0xe,
  0x2d,0xb2,0xc1,0x60,0x80,0xd,0x85,0x42,0xec,0xdc,0xdc,0x1c,0x1b,0xe,0x87,0xab,
  0xd8,0xa7,0xec,0xac,0xc3,0xe1,0x60,0xa7,0xa7,0xa7,0xef,0xa7,0x52,0x29,0xd6,0xe9,
  0x74,0xdc,0xc1,0xf1,0xfe,0x3a,0xe8,0xec,0xea,0x14,0x3b,0x66,0x9c,0x1b,0x53,0xd1,
  0xef,0x50,0x20,0xea,0x42,0xd9,0xcc,0xa,0xff,0x17,0xcb,0x48,0x78,0x27,0xc3,0x8,
  0x30,0x55,0x84,0x44,0x42,0x92,0x78,0x22,0x8e,0xd6,0xd6,0xd6,0xd0,0xf4,0x8c,0x7d,
  0xab,0xbd,0xbd,0x7d,0x7,0x34,0x35,0x49,0x60,0xef,0x3e,0xf1,0xb1,0x57,0x5e,0x6a,
  0xd5,0x35,0x4b,0x5b,0x54,0x12,0xac,0x49,0x83,0x61,0x98,0x16,0xc3,0x24,0x8f,0x90,
  0xf0,0x48,0x9b,0xa5,0x5a,0xa9,0x14,0xd3,0x60,0x52,0x4c,0xc5,0xaf,0x75,0xe2,0xbd,
  0xe2,0x77,0xeb,0xeb,0x1b,0x6a,0x60,0x74,0x74,0x14,0x3a,0x3a,0x3a,0xe0,0xf5,0x23,
  0x6d,0x20,0x97,0xcb,0x40,0x2e,0x93,0x83,0x4c,0x26,0xe3,0x91,0x3f,0x62,0xfb,0x8c,
  0xaf,0xcb,0x1f,0xac,0x5,0x8d,0xcd,0x66,0x83,0xff,0x0,0x72,0xd0,0x33,0x38,0xf3,
  0xfd,0x1c,0xe6,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // jabberdisk.png
  0x0,0xe,
  0xf,0x8f,0xda,0x27,
  0x0,0x6a,
  0x0,0x61,0x0,0x62,0x0,0x62,0x0,0x65,0x0,0x72,0x0,0x64,0x0,0x69,0x0,0x73,0x0,0x6b,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons/jabberdisk.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/jabberdiskplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/jabberdiskplugin/jabberdisk.png
  0x0,0x0,0x4,0x10,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xd,0xd7,0x0,0x0,0xd,0xd7,
  0x1,0x42,0x28,0x9b,0x78,0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,
  0x74,0x77,0x61,0x72,0x65,0x0,0x77,0x77,0x77,0x2e,0x69,0x6e,0x6b,0x73,0x63,0x61,
  0x70,0x65,0x2e,0x6f,0x72,0x67,0x9b,0xee,0x3c,0x1a,0x0,0x0,0x3,0x9d,0x49,0x44,
  0x41,0x54,0x78,0xda,0x45,0x90,0x6b,0x4c,0x5b,0x65,0x18,0xc7,0x1f,0x6,0x35,0x31,
  0x9b,0x9b,0x42,0x8c,0xc1,0x68,0xb7,0xc4,0x65,0x86,0x9e,0x32,0x74,0x99,0xd1,0x80,
  0x6b,0xb3,0x2f,0x26,0xe,0xa3,0xc1,0xb,0xe1,0x83,0x31,0x4b,0x16,0x81,0xd1,0xae,
  0x37,0x39,0x20,0x2d,0x3d,0xe7,0x74,0x2d,0x44,0xb1,0x68,0x3a,0xa7,0xc6,0xdb,0x62,
  0xb2,0xb,0x9b,0x1f,0x4c,0x18,0x85,0xb5,0xa1,0x6d,0xb6,0x5e,0x29,0x50,0x7a,0x3b,
  0xa5,0x3d,0x2d,0xbd,0x84,0xb1,0x69,0x14,0x62,0x5c,0x18,0xd9,0x4e,0xed,0x79,0x3d,
  0xa7,0x9b,0xe3,0xc3,0xef,0xbd,0x3d,0xcf,0xff,0xff,0xfe,0xdf,0x17,0x28,0x8a,0x2,
  0x8a,0x22,0x81,0x22,0xf9,0xd9,0x44,0xc0,0xe9,0xc1,0x2f,0x60,0xc0,0x64,0x82,0xe1,
  0x89,0x63,0x30,0xe0,0x6a,0xe6,0x69,0x1,0xe3,0x64,0x1b,0xe0,0x63,0x5a,0x30,0xf5,
  0x8f,0x3,0x45,0x90,0x40,0xfe,0xdf,0xcf,0x6b,0xab,0x83,0xb0,0x11,0xe,0x9,0x83,
  0x19,0x86,0xbf,0xee,0x1,0x65,0xf0,0x80,0xa8,0xc7,0xfb,0x44,0xab,0xda,0xf7,0x7c,
  0xbf,0xda,0x2f,0xd6,0xf5,0xf9,0xf7,0xb4,0x2a,0x23,0xcf,0xee,0x56,0x4f,0xbc,0x57,
  0x4b,0x10,0xa7,0x81,0x24,0x1f,0x98,0x8,0x54,0xd,0x8,0x8a,0x0,0x13,0x2f,0x1e,
  0xb4,0xea,0xa0,0x97,0xde,0xbd,0x53,0xe5,0x6b,0xc0,0x6d,0x8b,0x5d,0x7f,0x5f,0x2d,
  0x59,0xd0,0x54,0x69,0x4,0xd9,0x22,0x5d,0x7f,0xa9,0x7c,0xcf,0xf4,0xab,0xf2,0x8f,
  0x35,0x1a,0x7e,0xf8,0xb0,0x96,0x1a,0x1a,0xad,0x6a,0x84,0x8b,0x1f,0xba,0x11,0x40,
  0xe,0x8d,0x80,0x7e,0xf2,0x88,0x48,0x19,0xd9,0x79,0xd4,0xe8,0x6b,0xbb,0x65,0x64,
  0xa4,0xff,0x10,0xcb,0x2d,0xeb,0x86,0xe5,0xe6,0xd,0x82,0x91,0x6e,0x1a,0x3,0xad,
  0x37,0x95,0xe1,0x27,0xdf,0x1a,0x9c,0x17,0x3f,0x45,0x59,0xc,0x40,0x1a,0xa9,0xed,
  0x4,0x24,0xc9,0xbb,0xd,0x9b,0x6b,0x3e,0xf5,0x4b,0x1e,0x57,0x2e,0x36,0x74,0x8f,
  0x2d,0xbd,0x76,0x77,0xb6,0x70,0x68,0x73,0x8c,0x7e,0xee,0xde,0x99,0xd4,0x3e,0xf6,
  0x5b,0xe6,0x85,0x3b,0xc6,0xc5,0x43,0x9b,0xea,0x50,0xa3,0xe,0xcf,0x3c,0xdd,0x48,
  0x58,0x35,0x35,0x24,0x9f,0x58,0x48,0xb1,0xfd,0x9e,0x61,0x33,0x28,0xed,0xfb,0xf7,
  0x9c,0xf0,0xd7,0xbd,0x6f,0x8,0x62,0x37,0x6f,0x94,0xe4,0x6c,0xb8,0xf4,0x46,0x39,
  0x58,0x7a,0xb3,0x7c,0x7e,0xe5,0xd5,0x7b,0x9f,0x4,0xe,0xac,0x76,0x7b,0x77,0x1d,
  0x3f,0x19,0xdc,0x25,0x26,0x3e,0xd7,0x2,0x65,0x34,0x57,0x2f,0x16,0xc,0xea,0x84,
  0x14,0xa,0x85,0xe2,0xf0,0xa5,0xa9,0x9f,0xf2,0x57,0x7c,0x5f,0xde,0x3a,0x3b,0x7f,
  0x7c,0x4b,0x9f,0x3c,0x58,0x19,0x5b,0x3e,0x5a,0xf9,0x8c,0xc7,0x98,0x7c,0xb9,0x72,
  0x76,0xfe,0xa3,0xad,0xb,0x7e,0xcb,0xef,0x17,0xec,0x67,0xa,0xa7,0x4e,0x29,0xe,
  0x93,0x64,0x35,0xf9,0xe,0x30,0x9b,0xcd,0x22,0x1c,0xc7,0x61,0xfc,0x2b,0xeb,0xb9,
  0xdb,0x6b,0x7f,0x20,0x9a,0x89,0x21,0x3f,0x33,0x89,0x7e,0xa4,0x3f,0x40,0xdf,0x17,
  0xdf,0xe1,0x79,0x1b,0xfd,0x9c,0xea,0x44,0xd7,0x99,0x5f,0x51,0x8c,0x9,0xa1,0xb5,
  0xd5,0xdb,0xc8,0x3a,0x6e,0x3d,0x87,0xf,0xe0,0x60,0x32,0x99,0x44,0x60,0xb1,0x8c,
  0x80,0x46,0xa3,0x6e,0xf0,0x78,0xdc,0xeb,0xa5,0x52,0xe9,0xdf,0x4c,0x26,0x55,0x5e,
  0x88,0xc5,0xb8,0x1b,0x9e,0x6e,0x2e,0x10,0x3f,0xc8,0x79,0x63,0x12,0xee,0xba,0xe7,
  0x63,0x2e,0x42,0xc7,0xb9,0x74,0x86,0x2e,0xb,0x3d,0x6e,0x8f,0x6b,0x5d,0xa3,0xd5,
  0xd4,0x5b,0x2c,0x16,0x0,0xbd,0x5e,0xf,0x7a,0xc3,0x50,0x37,0xc3,0x30,0x28,0x9d,
  0x4e,0xb3,0x99,0x4c,0x86,0x4b,0xd1,0x29,0xce,0xeb,0xf5,0xa2,0x6b,0x57,0xcf,0x23,
  0xfb,0x6f,0xbf,0x20,0x97,0xcb,0x8d,0x96,0x96,0xa2,0x1c,0x5f,0xe7,0x1e,0xf6,0x20,
  0x5e,0x73,0x42,0xf8,0x3f,0xe8,0xed,0xed,0x11,0x5d,0xbe,0x3c,0xe1,0xcf,0x17,0x72,
  0x5c,0x86,0xc9,0x94,0xf3,0xf9,0x3c,0xc7,0x83,0xf2,0x85,0x3c,0xca,0xae,0x94,0x10,
  0x93,0x2b,0xa2,0x5c,0x2e,0x87,0xa,0xfc,0xbe,0x50,0x28,0x70,0xd9,0x6c,0xb6,0xcc,
  0xd7,0xb8,0x4b,0x13,0x17,0x83,0x6a,0xb5,0x1a,0xa0,0xaf,0xef,0xe4,0xfe,0xd9,0x59,
  0xe7,0x46,0x3e,0xbd,0xca,0xc5,0xa3,0xc9,0x4a,0x34,0x16,0x45,0xf1,0x78,0x1c,0x25,
  0x12,0x9,0x94,0x4c,0x26,0x10,0x4d,0x27,0x79,0x68,0xb4,0xb0,0xb0,0x80,0x22,0x91,
  0x88,0x30,0x57,0x8a,0xc5,0x22,0xe7,0x72,0xbb,0xee,0x2a,0x14,0x7d,0xb5,0xa0,0xd1,
  0xaa,0x5e,0x74,0xce,0xcc,0xfe,0xf9,0xcd,0x35,0x9c,0x9d,0x74,0x5f,0xbc,0x1f,0xe,
  0x2d,0xb2,0xc1,0x60,0x80,0xd,0x85,0x42,0xec,0xdc,0xdc,0x1c,0x1b,0xe,0x87,0xab,
  0xd8,0xa7,0xec,0xac,0xc3,0xe1,0x60,0xa7,0xa7,0xa7,0xef,0xa7,0x52,0x29,0xd6,0xe9,
  0x74,0xdc,0xc1,0xf1,0xfe,0x3a,0xe8,0xec,0xea,0x14,0x3b,0x66,0x9c,0x1b,0x53,0xd1,
  0xef,0x50,0x20,0xea,0x42,0xd9,0xcc,0xa,0xff,0x17,0xcb,0x48,0x78,0x27,0xc3,0x8,
  0x30,0x55,0x84,0x44,0x42,0x92,0x78,0x22,0x8e,0xd6,0xd6,0xd6,0xd0,0xf4,0x8c,0x7d,
  0xab,0xbd,0xbd,0x7d,0x7,0x34,0x35,0x49,0x60,0xef,0x3e,0xf1,0xb1,0x57,0x5e,0x6a,
  0xd5,0x35,0x4b,0x5b,0x54,0x12,0xac,0x49,0x83,0x61,0x98,0x16,0xc3,0x24,0x8f,0x90,
  0xf0,0x48,0x9b,0xa5,0x5a,0xa9,0x14,0xd3,0x60,0x52,0x4c,0xc5,0xaf,0x75,0xe2,0xbd,
  0xe2,0x77,0xeb,0xeb,0x1b,0x6a,0x60,0x74,0x74,0x14,0x3a,0x3a,0x3a,0xe0,0xf5,0x23,
  0x6d,0x20,0x97,0xcb,0x40,0x2e,0x93,0x83,0x4c,0x26,0xe3,0x91,0x3f,0x62,0xfb,0x8c,
  0xaf,0xcb,0x1f,0xac,0x5,0x8d,0xcd,0x66,0x83,0xff,0x0,0x72,0xd0,0x33,0x38,0xf3,
  0xfd,0x1c,0xe6,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // jabberdisk.png
  0x0,0xe,
  0xf,0x8f,0xda,0x27,
  0x0,0x6a,
  0x0,0x61,0x0,0x62,0x0,0x62,0x0,0x65,0x0,0x72,0x0,0x64,0x0,0x69,0x0,0x73,0x0,0x6b,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons/jabberdisk.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}
